FaceAutoCaptureWidgetController class final

Controller for managing the Face Auto Capture process.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestCapture({bool isFacePresenceRequired = false}) Future<void>
Request capture of the next detection. If isFacePresenceRequired is true, the result will be captured only if a face is detected with defined quality attributes. Otherwise, the result will be captured regardless of the face presence. Default is false.
start() Future<void>
Start the face auto capture process.
stop() Future<void>
Stop the process.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited